@@ -12,7 +12,7 @@
 namespace Symfony\Component\Security\Acl\Dbal;
 
 use Doctrine\DBAL\Connection;
-use Doctrine\DBAL\Driver\Statement;
+use Doctrine\DBAL\Result;
 use Symfony\Component\Security\Acl\Domain\Acl;
 use Symfony\Component\Security\Acl\Domain\Entry;
 use Symfony\Component\Security\Acl\Domain\FieldEntry;
@@ -36,7 +36,7 @@ use Symfony\Component\Security\Acl\Model\PermissionGrantingStrategyInterface;
  */
 class AclProvider implements AclProviderInterface
 {
-    const MAX_BATCH_SIZE = 30;
+    public const MAX_BATCH_SIZE = 30;
 
     /**
      * @var AclCacheInterface|null
@@ -56,11 +56,6 @@ class AclProvider implements AclProviderInterface
      */
     private $permissionGrantingStrategy;
 
-    /**
-     * Constructor.
-     *
-     * @param AclCacheInterface $cache
-     */
     public function __construct(Connection $connection, PermissionGrantingStrategyInterface $permissionGrantingStrategy, array $options, AclCacheInterface $cache = null)
     {
         $this->cache = $cache;
@@ -77,7 +72,7 @@ class AclProvider implements AclProviderInterface
         $sql = $this->getFindChildrenSql($parentOid, $directChildrenOnly);
 
         $children = [];
-        foreach ($this->connection->executeQuery($sql)->fetchAll() as $data) {
+        foreach ($this->connection->executeQuery($sql)->fetchAllAssociative() as $data) {
             $children[] = new ObjectIdentity($data['object_identifier'], $data['class_type']);
         }
 
@@ -97,6 +92,7 @@ class AclProvider implements AclProviderInterface
      */
     public function findAcls(array $oids, array $sids = [])
     {
+        /** @var \SplObjectStorage<ObjectIdentityInterface,AclInterface> */
         $result = new \SplObjectStorage();
         $currentBatch = [];
         $oidLookup = [];
@@ -249,7 +245,7 @@ class AclProvider implements AclProviderInterface
                 {$this->options['oid_table_name']} o
             INNER JOIN {$this->options['class_table_name']} c ON c.id = o.class_id
             LEFT JOIN {$this->options['entry_table_name']} e ON (
-                e.class_id = o.class_id AND (e.object_identity_id = o.id OR {$this->connection->getDatabasePlatform()->getIsNullExpression('e.object_identity_id')})
+                e.class_id = o.class_id AND (e.object_identity_id = o.id OR e.object_identity_id IS NULL)
             )
             LEFT JOIN {$this->options['sid_table_name']} s ON (
                 s.id = e.security_identity_id
@@ -384,7 +380,7 @@ QUERY;
      */
     final protected function retrieveObjectIdentityPrimaryKey(ObjectIdentityInterface $oid)
     {
-        return $this->connection->executeQuery($this->getSelectObjectIdentityIdSql($oid))->fetchColumn();
+        return $this->connection->executeQuery($this->getSelectObjectIdentityIdSql($oid))->fetchOne();
     }
 
     /**
@@ -421,7 +417,7 @@ QUERY;
         $sql = $this->getAncestorLookupSql($batch);
 
         $ancestorIds = [];
-        foreach ($this->connection->executeQuery($sql)->fetchAll() as $data) {
+        foreach ($this->connection->executeQuery($sql)->fetchAllAssociative() as $data) {
             // FIXME: skip ancestors which are cached
             // Fix: Oracle returns keys in uppercase
             $ancestorIds[] = reset($data);
@@ -433,8 +429,6 @@ QUERY;
     /**
      * Does either overwrite the passed ACE, or saves it in the global identity
      * map to ensure every ACE only gets instantiated once.
-     *
-     * @param array &$aces
      */
     private function doUpdateAceIdentityMap(array &$aces)
     {
@@ -451,7 +445,7 @@ QUERY;
      * This method is called for object identities which could not be retrieved
      * from the cache, and for which thus a database query is required.
      *
-     * @return \SplObjectStorage mapping object identities to ACL instances
+     * @return \SplObjectStorage<ObjectIdentityInterface,AclInterface> mapping object identities to ACL instances
      *
      * @throws AclNotFoundException
      */
@@ -477,22 +471,24 @@ QUERY;
      * Keep in mind that changes to this method might severely reduce the
      * performance of the entire ACL system.
      *
-     * @return \SplObjectStorage
+     * @return \SplObjectStorage<ObjectIdentityInterface,AclInterface>
      *
      * @throws \RuntimeException
      */
-    private function hydrateObjectIdentities(Statement $stmt, array $oidLookup, array $sids)
+    private function hydrateObjectIdentities(Result $stmt, array $oidLookup, array $sids)
     {
+        /** @var \SplObjectStorage<Acl,string> */
         $parentIdToFill = new \SplObjectStorage();
         $acls = $aces = $emptyArray = [];
         $oidCache = $oidLookup;
+        /** @var \SplObjectStorage<ObjectIdentityInterface,AclInterface> */
         $result = new \SplObjectStorage();
         $loadedAces = &$this->loadedAces;
         $loadedAcls = &$this->loadedAcls;
         $permissionGrantingStrategy = $this->permissionGrantingStrategy;
 
         // we need these to set protected properties on hydrated objects
-        $aclReflection = new \ReflectionClass('Symfony\Component\Security\Acl\Domain\Acl');
+        $aclReflection = new \ReflectionClass(Acl::class);
         $aclClassAcesProperty = $aclReflection->getProperty('classAces');
         $aclClassAcesProperty->setAccessible(true);
         $aclClassFieldAcesProperty = $aclReflection->getProperty('classFieldAces');
@@ -506,8 +502,8 @@ QUERY;
 
         // fetchAll() consumes more memory than consecutive calls to fetch(),
         // but it is faster
-        foreach ($stmt->fetchAll(\PDO::FETCH_NUM) as $data) {
-            list($aclId,
+        foreach ($stmt->fetchAllNumeric() as $data) {
+            [$aclId,
                  $objectIdentifier,
                  $parentObjectIdentityId,
                  $entriesInheriting,
@@ -522,7 +518,10 @@ QUERY;
                  $auditSuccess,
                  $auditFailure,
                  $username,
-                 $securityIdentifier) = array_values($data);
+                 $securityIdentifier] = array_values($data);
+
+            // FIX: remove duplicate slashes
+            $classType = str_replace('\\\\', '\\', $classType);
 
             // has the ACL been hydrated during this hydration cycle?
             if (isset($acls[$aclId])) {
