@@ -13,6 +13,8 @@ namespace Symfony\Component\Security\Acl\Dbal;
 
 use Doctrine\DBAL\Connection;
 use Doctrine\Persistence\PropertyChangedListener;
+use Symfony\Component\Security\Acl\Domain\Acl;
+use Symfony\Component\Security\Acl\Domain\Entry;
 use Symfony\Component\Security\Acl\Domain\RoleSecurityIdentity;
 use Symfony\Component\Security\Acl\Domain\UserSecurityIdentity;
 use Symfony\Component\Security\Acl\Exception\AclAlreadyExistsException;
@@ -60,7 +62,7 @@ class MutableAclProvider extends AclProvider implements MutableAclProviderInterf
             $this->createObjectIdentity($oid);
 
             $pk = $this->retrieveObjectIdentityPrimaryKey($oid);
-            $this->connection->executeUpdate($this->getInsertObjectIdentityRelationSql($pk, $pk));
+            $this->connection->executeStatement($this->getInsertObjectIdentityRelationSql($pk, $pk));
 
             $this->connection->commit();
         } catch (\Exception $e) {
@@ -117,7 +119,7 @@ class MutableAclProvider extends AclProvider implements MutableAclProviderInterf
      */
     public function deleteSecurityIdentity(SecurityIdentityInterface $sid)
     {
-        $this->connection->executeUpdate($this->getDeleteSecurityIdentityIdSql($sid));
+        $this->connection->executeStatement($this->getDeleteSecurityIdentityIdSql($sid));
     }
 
     /**
@@ -306,9 +308,9 @@ class MutableAclProvider extends AclProvider implements MutableAclProviderInterf
             // if there have been changes to shared properties, we need to synchronize other
             // ACL instances for object identities of the same type that are already in-memory
             if (\count($sharedPropertyChanges) > 0) {
-                $classAcesProperty = new \ReflectionProperty('Symfony\Component\Security\Acl\Domain\Acl', 'classAces');
+                $classAcesProperty = new \ReflectionProperty(Acl::class, 'classAces');
                 $classAcesProperty->setAccessible(true);
-                $classFieldAcesProperty = new \ReflectionProperty('Symfony\Component\Security\Acl\Domain\Acl', 'classFieldAces');
+                $classFieldAcesProperty = new \ReflectionProperty(Acl::class, 'classFieldAces');
                 $classFieldAcesProperty->setAccessible(true);
 
                 foreach ($this->loadedAcls[$acl->getObjectIdentity()->getType()] as $sameTypeAcl) {
@@ -332,7 +334,7 @@ class MutableAclProvider extends AclProvider implements MutableAclProviderInterf
 
             // persist any changes to the acl_object_identities table
             if (\count($sets) > 0) {
-                $this->connection->executeUpdate($this->getUpdateObjectIdentitySql($acl->getId(), $sets));
+                $this->connection->executeStatement($this->getUpdateObjectIdentitySql($acl->getId(), $sets));
             }
 
             $this->connection->commit();
@@ -370,7 +372,7 @@ class MutableAclProvider extends AclProvider implements MutableAclProviderInterf
      */
     public function updateUserSecurityIdentity(UserSecurityIdentity $usid, $oldUsername)
     {
-        $this->connection->executeUpdate($this->getUpdateUserSecurityIdentitySql($usid, $oldUsername));
+        $this->connection->executeStatement($this->getUpdateUserSecurityIdentitySql($usid, $oldUsername));
     }
 
     /**
@@ -576,25 +578,25 @@ QUERY;
     /**
      * Constructs the SQL for selecting an ACE.
      *
-     * @param int    $classId
-     * @param int    $oid
-     * @param string $field
-     * @param int    $order
+     * @param int         $classId
+     * @param int|null    $oid
+     * @param string|null $field
+     * @param int         $order
      *
      * @return string
      */
     protected function getSelectAccessControlEntryIdSql($classId, $oid, $field, $order)
     {
         return sprintf(
-            'SELECT id FROM %s WHERE class_id = %d AND %s AND %s AND ace_order = %d',
+            'SELECT id FROM %s WHERE class_id = %d AND object_identity_id %s AND field_name %s AND ace_order = %d',
             $this->options['entry_table_name'],
             $classId,
-            null === $oid ?
-                $this->connection->getDatabasePlatform()->getIsNullExpression('object_identity_id')
-                : 'object_identity_id = '.(int) $oid,
-            null === $field ?
-                $this->connection->getDatabasePlatform()->getIsNullExpression('field_name')
-                : 'field_name = '.$this->connection->quote($field),
+            null === $oid
+                ? 'IS NULL'
+                : '= '.(int) $oid,
+            null === $field
+                ? 'IS NULL'
+                : '= '.$this->connection->quote($field),
             $order
         );
     }
@@ -736,7 +738,7 @@ QUERY;
     {
         $classId = $this->createOrRetrieveClassId($oid->getType());
 
-        $this->connection->executeUpdate($this->getInsertObjectIdentitySql($oid->getIdentifier(), $classId, true));
+        $this->connection->executeStatement($this->getInsertObjectIdentitySql($oid->getIdentifier(), $classId, true));
     }
 
     /**
@@ -750,13 +752,13 @@ QUERY;
      */
     private function createOrRetrieveClassId($classType)
     {
-        if (false !== $id = $this->connection->executeQuery($this->getSelectClassIdSql($classType))->fetchColumn()) {
+        if (false !== $id = $this->connection->executeQuery($this->getSelectClassIdSql($classType))->fetchOne()) {
             return $id;
         }
 
-        $this->connection->executeUpdate($this->getInsertClassSql($classType));
+        $this->connection->executeStatement($this->getInsertClassSql($classType));
 
-        return $this->connection->executeQuery($this->getSelectClassIdSql($classType))->fetchColumn();
+        return $this->connection->executeQuery($this->getSelectClassIdSql($classType))->fetchOne();
     }
 
     /**
@@ -769,13 +771,13 @@ QUERY;
      */
     private function createOrRetrieveSecurityIdentityId(SecurityIdentityInterface $sid)
     {
-        if (false !== $id = $this->connection->executeQuery($this->getSelectSecurityIdentityIdSql($sid))->fetchColumn()) {
+        if (false !== $id = $this->connection->executeQuery($this->getSelectSecurityIdentityIdSql($sid))->fetchOne()) {
             return $id;
         }
 
-        $this->connection->executeUpdate($this->getInsertSecurityIdentitySql($sid));
+        $this->connection->executeStatement($this->getInsertSecurityIdentitySql($sid));
 
-        return $this->connection->executeQuery($this->getSelectSecurityIdentityIdSql($sid))->fetchColumn();
+        return $this->connection->executeQuery($this->getSelectSecurityIdentityIdSql($sid))->fetchOne();
     }
 
     /**
@@ -785,7 +787,7 @@ QUERY;
      */
     private function deleteAccessControlEntries($oidPK)
     {
-        $this->connection->executeUpdate($this->getDeleteAccessControlEntriesSql($oidPK));
+        $this->connection->executeStatement($this->getDeleteAccessControlEntriesSql($oidPK));
     }
 
     /**
@@ -795,7 +797,7 @@ QUERY;
      */
     private function deleteObjectIdentity($pk)
     {
-        $this->connection->executeUpdate($this->getDeleteObjectIdentitySql($pk));
+        $this->connection->executeStatement($this->getDeleteObjectIdentitySql($pk));
     }
 
     /**
@@ -805,7 +807,7 @@ QUERY;
      */
     private function deleteObjectIdentityRelations($pk)
     {
-        $this->connection->executeUpdate($this->getDeleteObjectIdentityRelationsSql($pk));
+        $this->connection->executeStatement($this->getDeleteObjectIdentityRelationsSql($pk));
     }
 
     /**
@@ -814,12 +816,12 @@ QUERY;
     private function regenerateAncestorRelations(AclInterface $acl)
     {
         $pk = $acl->getId();
-        $this->connection->executeUpdate($this->getDeleteObjectIdentityRelationsSql($pk));
-        $this->connection->executeUpdate($this->getInsertObjectIdentityRelationSql($pk, $pk));
+        $this->connection->executeStatement($this->getDeleteObjectIdentityRelationsSql($pk));
+        $this->connection->executeStatement($this->getInsertObjectIdentityRelationSql($pk, $pk));
 
         $parentAcl = $acl->getParentAcl();
         while (null !== $parentAcl) {
-            $this->connection->executeUpdate($this->getInsertObjectIdentityRelationSql($pk, $parentAcl->getId()));
+            $this->connection->executeStatement($this->getInsertObjectIdentityRelationSql($pk, $parentAcl->getId()));
 
             $parentAcl = $parentAcl->getParentAcl();
         }
@@ -854,11 +856,11 @@ QUERY;
 
                     $objectIdentityId = 'classFieldAces' === $name ? null : $ace->getAcl()->getId();
 
-                    $this->connection->executeUpdate($this->getInsertAccessControlEntrySql($classId, $objectIdentityId, $field, $i, $sid, $ace->getStrategy(), $ace->getMask(), $ace->isGranting(), $ace->isAuditSuccess(), $ace->isAuditFailure()));
-                    $aceId = $this->connection->executeQuery($this->getSelectAccessControlEntryIdSql($classId, $objectIdentityId, $field, $i))->fetchColumn();
+                    $this->connection->executeStatement($this->getInsertAccessControlEntrySql($classId, $objectIdentityId, $field, $i, $sid, $ace->getStrategy(), $ace->getMask(), $ace->isGranting(), $ace->isAuditSuccess(), $ace->isAuditFailure()));
+                    $aceId = $this->connection->executeQuery($this->getSelectAccessControlEntryIdSql($classId, $objectIdentityId, $field, $i))->fetchOne();
                     $this->loadedAces[$aceId] = $ace;
 
-                    $aceIdProperty = new \ReflectionProperty('Symfony\Component\Security\Acl\Domain\Entry', 'id');
+                    $aceIdProperty = new \ReflectionProperty(Entry::class, 'id');
                     $aceIdProperty->setAccessible(true);
                     $aceIdProperty->setValue($ace, (int) $aceId);
                 }
@@ -889,7 +891,7 @@ QUERY;
                 $ace = $old[$i];
 
                 if (!isset($currentIds[$ace->getId()])) {
-                    $this->connection->executeUpdate($this->getDeleteAccessControlEntrySql($ace->getId()));
+                    $this->connection->executeStatement($this->getDeleteAccessControlEntrySql($ace->getId()));
                     unset($this->loadedAces[$ace->getId()]);
                 }
             }
@@ -903,7 +905,7 @@ QUERY;
      */
     private function updateNewAceProperty($name, array $changes)
     {
-        list($old, $new) = $changes;
+        [$old, $new] = $changes;
 
         $sids = new \SplObjectStorage();
         $classIds = new \SplObjectStorage();
@@ -926,8 +928,8 @@ QUERY;
 
                 $objectIdentityId = 'classAces' === $name ? null : $ace->getAcl()->getId();
 
-                $this->connection->executeUpdate($this->getInsertAccessControlEntrySql($classId, $objectIdentityId, null, $i, $sid, $ace->getStrategy(), $ace->getMask(), $ace->isGranting(), $ace->isAuditSuccess(), $ace->isAuditFailure()));
-                $aceId = $this->connection->executeQuery($this->getSelectAccessControlEntryIdSql($classId, $objectIdentityId, null, $i))->fetchColumn();
+                $this->connection->executeStatement($this->getInsertAccessControlEntrySql($classId, $objectIdentityId, null, $i, $sid, $ace->getStrategy(), $ace->getMask(), $ace->isGranting(), $ace->isAuditSuccess(), $ace->isAuditFailure()));
+                $aceId = $this->connection->executeQuery($this->getSelectAccessControlEntryIdSql($classId, $objectIdentityId, null, $i))->fetchOne();
                 $this->loadedAces[$aceId] = $ace;
 
                 $aceIdProperty = new \ReflectionProperty($ace, 'id');
@@ -944,7 +946,7 @@ QUERY;
      */
     private function updateOldAceProperty($name, array $changes)
     {
-        list($old, $new) = $changes;
+        [$old, $new] = $changes;
         $currentIds = [];
 
         for ($i = 0, $c = \count($new); $i < $c; ++$i) {
@@ -959,7 +961,7 @@ QUERY;
             $ace = $old[$i];
 
             if (!isset($currentIds[$ace->getId()])) {
-                $this->connection->executeUpdate($this->getDeleteAccessControlEntrySql($ace->getId()));
+                $this->connection->executeStatement($this->getDeleteAccessControlEntrySql($ace->getId()));
                 unset($this->loadedAces[$ace->getId()]);
             }
         }
@@ -1005,6 +1007,6 @@ QUERY;
             $sets[] = sprintf('audit_failure = %s', $this->connection->getDatabasePlatform()->convertBooleans($propertyChanges['auditFailure'][1]));
         }
 
-        $this->connection->executeUpdate($this->getUpdateAccessControlEntrySql($ace->getId(), $sets));
+        $this->connection->executeStatement($this->getUpdateAccessControlEntrySql($ace->getId(), $sets));
     }
 }
