@@ -12,7 +12,9 @@
 namespace Symfony\Component\Security\Acl\Dbal;
 
 use Doctrine\DBAL\Connection;
+use Doctrine\DBAL\Platforms\SQLServerPlatform;
 use Doctrine\DBAL\Schema\Schema as BaseSchema;
+use Doctrine\DBAL\Schema\SchemaConfig;
 
 /**
  * The schema used for the ACL system.
@@ -22,20 +24,19 @@ use Doctrine\DBAL\Schema\Schema as BaseSchema;
 final class Schema extends BaseSchema
 {
     protected $options;
+    protected $platform;
 
     /**
-     * Constructor.
-     *
-     * @param array      $options    the names for tables
-     * @param Connection $connection
+     * @param array $options the names for tables
      */
     public function __construct(array $options, Connection $connection = null)
     {
-        $schemaConfig = null === $connection ? null : $connection->getSchemaManager()->createSchemaConfig();
+        $schemaConfig = $this->createSchemaConfig($connection);
 
         parent::__construct([], [], $schemaConfig);
 
         $this->options = $options;
+        $this->platform = $connection ? $connection->getDatabasePlatform() : null;
 
         $this->addClassTable();
         $this->addSecurityIdentitiesTable();
@@ -131,8 +132,13 @@ final class Schema extends BaseSchema
         $table->setPrimaryKey(['object_identity_id', 'ancestor_id']);
 
         $oidTable = $this->getTable($this->options['oid_table_name']);
-        $table->addForeignKeyConstraint($oidTable, ['object_identity_id'], ['id'], ['onDelete' => 'CASCADE', 'onUpdate' => 'CASCADE']);
-        $table->addForeignKeyConstraint($oidTable, ['ancestor_id'], ['id'], ['onDelete' => 'CASCADE', 'onUpdate' => 'CASCADE']);
+        $action = 'CASCADE';
+        if ($this->platform instanceof SQLServerPlatform) {
+            // MS SQL Server does not support recursive cascading
+            $action = 'NO ACTION';
+        }
+        $table->addForeignKeyConstraint($oidTable, ['object_identity_id'], ['id'], ['onDelete' => $action, 'onUpdate' => $action]);
+        $table->addForeignKeyConstraint($oidTable, ['ancestor_id'], ['id'], ['onDelete' => $action, 'onUpdate' => $action]);
     }
 
     /**
@@ -149,4 +155,18 @@ final class Schema extends BaseSchema
         $table->setPrimaryKey(['id']);
         $table->addUniqueIndex(['identifier', 'username']);
     }
+
+    private function createSchemaConfig(?Connection $connection): ?SchemaConfig
+    {
+        if (null === $connection) {
+            return null;
+        }
+
+        $schemaManager = method_exists($connection, 'createSchemaManager')
+            ? $connection->createSchemaManager()
+            : $connection->getSchemaManager()
+        ;
+
+        return $schemaManager->createSchemaConfig();
+    }
 }
