@@ -73,7 +73,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function deleteClassAce($index)
+    public function deleteClassAce(int $index)
     {
         $this->deleteAce('classAces', $index);
     }
@@ -81,7 +81,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function deleteClassFieldAce($index, $field)
+    public function deleteClassFieldAce(int $index, string $field)
     {
         $this->deleteFieldAce('classFieldAces', $index, $field);
     }
@@ -89,7 +89,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function deleteObjectAce($index)
+    public function deleteObjectAce(int $index)
     {
         $this->deleteAce('objectAces', $index);
     }
@@ -97,7 +97,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function deleteObjectFieldAce($index, $field)
+    public function deleteObjectFieldAce(int $index, string $field)
     {
         $this->deleteFieldAce('objectFieldAces', $index, $field);
     }
@@ -113,9 +113,9 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function getClassFieldAces($field)
+    public function getClassFieldAces(string $field)
     {
-        return isset($this->classFieldAces[$field]) ? $this->classFieldAces[$field] : [];
+        return $this->classFieldAces[$field] ?? [];
     }
 
     /**
@@ -129,9 +129,9 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function getObjectFieldAces($field)
+    public function getObjectFieldAces(string $field)
     {
-        return isset($this->objectFieldAces[$field]) ? $this->objectFieldAces[$field] : [];
+        return $this->objectFieldAces[$field] ?? [];
     }
 
     /**
@@ -161,7 +161,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function insertClassAce(SecurityIdentityInterface $sid, $mask, $index = 0, $granting = true, $strategy = null)
+    public function insertClassAce(SecurityIdentityInterface $sid, int $mask, int $index = 0, bool $granting = true, ?string $strategy = null)
     {
         $this->insertAce('classAces', $index, $mask, $sid, $granting, $strategy);
     }
@@ -169,7 +169,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function insertClassFieldAce($field, SecurityIdentityInterface $sid, $mask, $index = 0, $granting = true, $strategy = null)
+    public function insertClassFieldAce(string $field, SecurityIdentityInterface $sid, int $mask, int $index = 0, bool $granting = true, ?string $strategy = null)
     {
         $this->insertFieldAce('classFieldAces', $index, $field, $mask, $sid, $granting, $strategy);
     }
@@ -177,7 +177,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function insertObjectAce(SecurityIdentityInterface $sid, $mask, $index = 0, $granting = true, $strategy = null)
+    public function insertObjectAce(SecurityIdentityInterface $sid, int $mask, int $index = 0, bool $granting = true, ?string $strategy = null)
     {
         $this->insertAce('objectAces', $index, $mask, $sid, $granting, $strategy);
     }
@@ -185,7 +185,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function insertObjectFieldAce($field, SecurityIdentityInterface $sid, $mask, $index = 0, $granting = true, $strategy = null)
+    public function insertObjectFieldAce(string $field, SecurityIdentityInterface $sid, int $mask, int $index = 0, bool $granting = true, ?string $strategy = null)
     {
         $this->insertFieldAce('objectFieldAces', $index, $field, $mask, $sid, $granting, $strategy);
     }
@@ -201,7 +201,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function isFieldGranted($field, array $masks, array $securityIdentities, $administrativeMode = false)
+    public function isFieldGranted(string $field, array $masks, array $securityIdentities, bool $administrativeMode = false)
     {
         return $this->permissionGrantingStrategy->isFieldGranted($this, $field, $masks, $securityIdentities, $administrativeMode);
     }
@@ -209,7 +209,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function isGranted(array $masks, array $securityIdentities, $administrativeMode = false)
+    public function isGranted(array $masks, array $securityIdentities, bool $administrativeMode = false)
     {
         return $this->permissionGrantingStrategy->isGranted($this, $masks, $securityIdentities, $administrativeMode);
     }
@@ -217,17 +217,17 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function isSidLoaded($sids)
+    public function isSidLoaded($securityIdentities)
     {
         if (!$this->loadedSids) {
             return true;
         }
 
-        if (!\is_array($sids)) {
-            $sids = [$sids];
+        if (!\is_array($securityIdentities)) {
+            $securityIdentities = [$securityIdentities];
         }
 
-        foreach ($sids as $sid) {
+        foreach ($securityIdentities as $sid) {
             if (!$sid instanceof SecurityIdentityInterface) {
                 throw new \InvalidArgumentException('$sid must be an instance of SecurityIdentityInterface.');
             }
@@ -244,14 +244,9 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
         return true;
     }
 
-    /**
-     * Implementation for the \Serializable interface.
-     *
-     * @return string
-     */
-    public function serialize()
+    public function __serialize(): array
     {
-        return serialize([
+        return [
             null === $this->parentAcl ? null : $this->parentAcl->getId(),
             $this->objectIdentity,
             $this->classAces,
@@ -261,17 +256,12 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
             $this->id,
             $this->loadedSids,
             $this->entriesInheriting,
-        ]);
+        ];
     }
 
-    /**
-     * Implementation for the \Serializable interface.
-     *
-     * @param string $serialized
-     */
-    public function unserialize($serialized)
+    public function __unserialize(array $data): void
     {
-        list($this->parentAcl,
+        [$this->parentAcl,
              $this->objectIdentity,
              $this->classAces,
              $this->classFieldAces,
@@ -280,15 +270,37 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
              $this->id,
              $this->loadedSids,
              $this->entriesInheriting
-        ) = unserialize($serialized);
+        ] = $data;
 
         $this->listeners = [];
     }
 
+    /**
+     * @internal
+     * @final
+     *
+     * @return string
+     */
+    public function serialize()
+    {
+        return serialize($this->__serialize());
+    }
+
+    /**
+     * @internal
+     * @final
+     *
+     * @param string $serialized
+     */
+    public function unserialize($serialized)
+    {
+        $this->__unserialize(\is_array($serialized) ? $serialized : unserialize($serialized));
+    }
+
     /**
      * {@inheritdoc}
      */
-    public function setEntriesInheriting($boolean)
+    public function setEntriesInheriting(bool $boolean)
     {
         if ($this->entriesInheriting !== $boolean) {
             $this->onPropertyChanged('entriesInheriting', $this->entriesInheriting, $boolean);
@@ -299,7 +311,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function setParentAcl(AclInterface $acl = null)
+    public function setParentAcl(?AclInterface $acl = null)
     {
         if (null !== $acl && null === $acl->getId()) {
             throw new \InvalidArgumentException('$acl must have an ID.');
@@ -314,7 +326,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function updateClassAce($index, $mask, $strategy = null)
+    public function updateClassAce(int $index, int $mask, ?string $strategy = null)
     {
         $this->updateAce('classAces', $index, $mask, $strategy);
     }
@@ -322,7 +334,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function updateClassFieldAce($index, $field, $mask, $strategy = null)
+    public function updateClassFieldAce(int $index, string $field, int $mask, ?string $strategy = null)
     {
         $this->updateFieldAce('classFieldAces', $index, $field, $mask, $strategy);
     }
@@ -330,7 +342,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function updateObjectAce($index, $mask, $strategy = null)
+    public function updateObjectAce(int $index, int $mask, ?string $strategy = null)
     {
         $this->updateAce('objectAces', $index, $mask, $strategy);
     }
@@ -338,7 +350,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function updateObjectFieldAce($index, $field, $mask, $strategy = null)
+    public function updateObjectFieldAce(int $index, string $field, int $mask, ?string $strategy = null)
     {
         $this->updateFieldAce('objectFieldAces', $index, $field, $mask, $strategy);
     }
@@ -346,7 +358,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function updateClassAuditing($index, $auditSuccess, $auditFailure)
+    public function updateClassAuditing(int $index, bool $auditSuccess, bool $auditFailure)
     {
         $this->updateAuditing($this->classAces, $index, $auditSuccess, $auditFailure);
     }
@@ -354,7 +366,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function updateClassFieldAuditing($index, $field, $auditSuccess, $auditFailure)
+    public function updateClassFieldAuditing(int $index, string $field, bool $auditSuccess, bool $auditFailure)
     {
         if (!isset($this->classFieldAces[$field])) {
             throw new \InvalidArgumentException(sprintf('There are no ACEs for field "%s".', $field));
@@ -366,7 +378,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function updateObjectAuditing($index, $auditSuccess, $auditFailure)
+    public function updateObjectAuditing(int $index, bool $auditSuccess, bool $auditFailure)
     {
         $this->updateAuditing($this->objectAces, $index, $auditSuccess, $auditFailure);
     }
@@ -374,7 +386,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * {@inheritdoc}
      */
-    public function updateObjectFieldAuditing($index, $field, $auditSuccess, $auditFailure)
+    public function updateObjectFieldAuditing(int $index, string $field, bool $auditSuccess, bool $auditFailure)
     {
         if (!isset($this->objectFieldAces[$field])) {
             throw new \InvalidArgumentException(sprintf('There are no ACEs for field "%s".', $field));
@@ -497,7 +509,8 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
      */
     private function insertFieldAce($property, $index, $field, $mask, SecurityIdentityInterface $sid, $granting, $strategy = null)
     {
-        if (0 === \strlen($field)) {
+        $field = (string) $field;
+        if ('' === $field) {
             throw new \InvalidArgumentException('$field cannot be empty.');
         }
 
@@ -570,10 +583,9 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     /**
      * Updates auditing for an ACE.
      *
-     * @param array &$aces
-     * @param int   $index
-     * @param bool  $auditSuccess
-     * @param bool  $auditFailure
+     * @param int  $index
+     * @param bool $auditSuccess
+     * @param bool $auditFailure
      *
      * @throws \OutOfBoundsException
      */
@@ -608,7 +620,8 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
      */
     private function updateFieldAce($property, $index, $field, $mask, $strategy = null)
     {
-        if (0 === \strlen($field)) {
+        $field = (string) $field;
+        if ('' === $field) {
             throw new \InvalidArgumentException('$field cannot be empty.');
         }
 
